# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProfileMain(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domino': 'DominoCommons',
        'version': 'str',
        'database_type': 'str',
        'vat': 'str',
        'insyco_xml_file': 'str',
        'maximal_size_mb': 'str',
        'item_bank_account_list': 'list[str]',
        'item_bank_account_default': 'str',
        'avizo_1': 'str',
        'avizo_2': 'str',
        'avizo_3': 'str',
        'avizo_4': 'str',
        'avizo_5': 'str',
        'avizo_6': 'str',
        'avizo_7': 'str',
        'evidence_status_shortcut_list': 'list[str]',
        'evidence_status_list': 'list[str]',
        'cover_status_shortcut_list': 'list[str]',
        'cover_status_list': 'list[str]',
        'fields_to_log_list': 'list[str]',
        'bcc_list': 'list[str]',
        'budget_department_head': 'str',
        'alpha_help_path_list': 'list[str]',
        'ghoul_help_path_list': 'list[str]',
        'profile_db_pub_list': 'list[str]',
        'info_db_alpha_list': 'list[str]',
        'info_db_ghoul_list': 'list[str]'
    }

    attribute_map = {
        'domino': 'domino',
        'version': 'version',
        'database_type': 'database_type',
        'vat': 'vat',
        'insyco_xml_file': 'insyco_xml_file',
        'maximal_size_mb': 'maximal_size_mb',
        'item_bank_account_list': 'item_bank_account_list',
        'item_bank_account_default': 'item_bank_account_default',
        'avizo_1': 'avizo_1',
        'avizo_2': 'avizo_2',
        'avizo_3': 'avizo_3',
        'avizo_4': 'avizo_4',
        'avizo_5': 'avizo_5',
        'avizo_6': 'avizo_6',
        'avizo_7': 'avizo_7',
        'evidence_status_shortcut_list': 'evidence_status_shortcut_list',
        'evidence_status_list': 'evidence_status_list',
        'cover_status_shortcut_list': 'cover_status_shortcut_list',
        'cover_status_list': 'cover_status_list',
        'fields_to_log_list': 'fields_to_log_list',
        'bcc_list': 'bcc_list',
        'budget_department_head': 'budget_department_head',
        'alpha_help_path_list': 'alpha_help_path_list',
        'ghoul_help_path_list': 'ghoul_help_path_list',
        'profile_db_pub_list': 'profile_db_pub_list',
        'info_db_alpha_list': 'info_db_alpha_list',
        'info_db_ghoul_list': 'info_db_ghoul_list'
    }

    def __init__(self, domino=None, version=None, database_type=None, vat=None, insyco_xml_file=None, maximal_size_mb=None, item_bank_account_list=None, item_bank_account_default=None, avizo_1=None, avizo_2=None, avizo_3=None, avizo_4=None, avizo_5=None, avizo_6=None, avizo_7=None, evidence_status_shortcut_list=None, evidence_status_list=None, cover_status_shortcut_list=None, cover_status_list=None, fields_to_log_list=None, bcc_list=None, budget_department_head=None, alpha_help_path_list=None, ghoul_help_path_list=None, profile_db_pub_list=None, info_db_alpha_list=None, info_db_ghoul_list=None):  # noqa: E501
        """ProfileMain - a model defined in Swagger"""  # noqa: E501
        self._domino = None
        self._version = None
        self._database_type = None
        self._vat = None
        self._insyco_xml_file = None
        self._maximal_size_mb = None
        self._item_bank_account_list = None
        self._item_bank_account_default = None
        self._avizo_1 = None
        self._avizo_2 = None
        self._avizo_3 = None
        self._avizo_4 = None
        self._avizo_5 = None
        self._avizo_6 = None
        self._avizo_7 = None
        self._evidence_status_shortcut_list = None
        self._evidence_status_list = None
        self._cover_status_shortcut_list = None
        self._cover_status_list = None
        self._fields_to_log_list = None
        self._bcc_list = None
        self._budget_department_head = None
        self._alpha_help_path_list = None
        self._ghoul_help_path_list = None
        self._profile_db_pub_list = None
        self._info_db_alpha_list = None
        self._info_db_ghoul_list = None
        self.discriminator = None
        if domino is not None:
            self.domino = domino
        if version is not None:
            self.version = version
        if database_type is not None:
            self.database_type = database_type
        if vat is not None:
            self.vat = vat
        if insyco_xml_file is not None:
            self.insyco_xml_file = insyco_xml_file
        if maximal_size_mb is not None:
            self.maximal_size_mb = maximal_size_mb
        if item_bank_account_list is not None:
            self.item_bank_account_list = item_bank_account_list
        if item_bank_account_default is not None:
            self.item_bank_account_default = item_bank_account_default
        if avizo_1 is not None:
            self.avizo_1 = avizo_1
        if avizo_2 is not None:
            self.avizo_2 = avizo_2
        if avizo_3 is not None:
            self.avizo_3 = avizo_3
        if avizo_4 is not None:
            self.avizo_4 = avizo_4
        if avizo_5 is not None:
            self.avizo_5 = avizo_5
        if avizo_6 is not None:
            self.avizo_6 = avizo_6
        if avizo_7 is not None:
            self.avizo_7 = avizo_7
        if evidence_status_shortcut_list is not None:
            self.evidence_status_shortcut_list = evidence_status_shortcut_list
        if evidence_status_list is not None:
            self.evidence_status_list = evidence_status_list
        if cover_status_shortcut_list is not None:
            self.cover_status_shortcut_list = cover_status_shortcut_list
        if cover_status_list is not None:
            self.cover_status_list = cover_status_list
        if fields_to_log_list is not None:
            self.fields_to_log_list = fields_to_log_list
        if bcc_list is not None:
            self.bcc_list = bcc_list
        if budget_department_head is not None:
            self.budget_department_head = budget_department_head
        if alpha_help_path_list is not None:
            self.alpha_help_path_list = alpha_help_path_list
        if ghoul_help_path_list is not None:
            self.ghoul_help_path_list = ghoul_help_path_list
        if profile_db_pub_list is not None:
            self.profile_db_pub_list = profile_db_pub_list
        if info_db_alpha_list is not None:
            self.info_db_alpha_list = info_db_alpha_list
        if info_db_ghoul_list is not None:
            self.info_db_ghoul_list = info_db_ghoul_list

    @property
    def domino(self):
        """Gets the domino of this ProfileMain.  # noqa: E501


        :return: The domino of this ProfileMain.  # noqa: E501
        :rtype: DominoCommons
        """
        return self._domino

    @domino.setter
    def domino(self, domino):
        """Sets the domino of this ProfileMain.


        :param domino: The domino of this ProfileMain.  # noqa: E501
        :type: DominoCommons
        """

        self._domino = domino

    @property
    def version(self):
        """Gets the version of this ProfileMain.  # noqa: E501

        Verze aplikace Notes  # noqa: E501

        :return: The version of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ProfileMain.

        Verze aplikace Notes  # noqa: E501

        :param version: The version of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def database_type(self):
        """Gets the database_type of this ProfileMain.  # noqa: E501

        DatabaseType - typ databáze  # noqa: E501

        :return: The database_type of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """Sets the database_type of this ProfileMain.

        DatabaseType - typ databáze  # noqa: E501

        :param database_type: The database_type of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._database_type = database_type

    @property
    def vat(self):
        """Gets the vat of this ProfileMain.  # noqa: E501

        VAT  Sazba DPH  # noqa: E501

        :return: The vat of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._vat

    @vat.setter
    def vat(self, vat):
        """Sets the vat of this ProfileMain.

        VAT  Sazba DPH  # noqa: E501

        :param vat: The vat of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._vat = vat

    @property
    def insyco_xml_file(self):
        """Gets the insyco_xml_file of this ProfileMain.  # noqa: E501

        insycoXmlFile  Cesta pro export XML pro insyco  # noqa: E501

        :return: The insyco_xml_file of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._insyco_xml_file

    @insyco_xml_file.setter
    def insyco_xml_file(self, insyco_xml_file):
        """Sets the insyco_xml_file of this ProfileMain.

        insycoXmlFile  Cesta pro export XML pro insyco  # noqa: E501

        :param insyco_xml_file: The insyco_xml_file of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._insyco_xml_file = insyco_xml_file

    @property
    def maximal_size_mb(self):
        """Gets the maximal_size_mb of this ProfileMain.  # noqa: E501

        maximalSize  Maximální velikost EL/KL (MB)  # noqa: E501

        :return: The maximal_size_mb of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._maximal_size_mb

    @maximal_size_mb.setter
    def maximal_size_mb(self, maximal_size_mb):
        """Sets the maximal_size_mb of this ProfileMain.

        maximalSize  Maximální velikost EL/KL (MB)  # noqa: E501

        :param maximal_size_mb: The maximal_size_mb of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._maximal_size_mb = maximal_size_mb

    @property
    def item_bank_account_list(self):
        """Gets the item_bank_account_list of this ProfileMain.  # noqa: E501

        item_bank_account_list  Seznam účtů pro financování rozpočtových položek (platební kalendář)|   # noqa: E501

        :return: The item_bank_account_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._item_bank_account_list

    @item_bank_account_list.setter
    def item_bank_account_list(self, item_bank_account_list):
        """Sets the item_bank_account_list of this ProfileMain.

        item_bank_account_list  Seznam účtů pro financování rozpočtových položek (platební kalendář)|   # noqa: E501

        :param item_bank_account_list: The item_bank_account_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._item_bank_account_list = item_bank_account_list

    @property
    def item_bank_account_default(self):
        """Gets the item_bank_account_default of this ProfileMain.  # noqa: E501

        item_bank_account_default  Výchozí účet pro financování rozpočtových položek (platební kalendář)|   # noqa: E501

        :return: The item_bank_account_default of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._item_bank_account_default

    @item_bank_account_default.setter
    def item_bank_account_default(self, item_bank_account_default):
        """Sets the item_bank_account_default of this ProfileMain.

        item_bank_account_default  Výchozí účet pro financování rozpočtových položek (platební kalendář)|   # noqa: E501

        :param item_bank_account_default: The item_bank_account_default of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._item_bank_account_default = item_bank_account_default

    @property
    def avizo_1(self):
        """Gets the avizo_1 of this ProfileMain.  # noqa: E501

        avizo_1  Předmět notifikačního emailu  při poslání  k podpisu příkazci operace|   # noqa: E501

        :return: The avizo_1 of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._avizo_1

    @avizo_1.setter
    def avizo_1(self, avizo_1):
        """Sets the avizo_1 of this ProfileMain.

        avizo_1  Předmět notifikačního emailu  při poslání  k podpisu příkazci operace|   # noqa: E501

        :param avizo_1: The avizo_1 of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._avizo_1 = avizo_1

    @property
    def avizo_2(self):
        """Gets the avizo_2 of this ProfileMain.  # noqa: E501

        avizo_2  Předmět notifikačního emailu  při poslání  k podpisu vrchnímu řediteli|   # noqa: E501

        :return: The avizo_2 of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._avizo_2

    @avizo_2.setter
    def avizo_2(self, avizo_2):
        """Sets the avizo_2 of this ProfileMain.

        avizo_2  Předmět notifikačního emailu  při poslání  k podpisu vrchnímu řediteli|   # noqa: E501

        :param avizo_2: The avizo_2 of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._avizo_2 = avizo_2

    @property
    def avizo_3(self):
        """Gets the avizo_3 of this ProfileMain.  # noqa: E501

        avizo_3  Předmět notifikačního emailu  při poslání  k podpisu příkazci operace - NM|   # noqa: E501

        :return: The avizo_3 of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._avizo_3

    @avizo_3.setter
    def avizo_3(self, avizo_3):
        """Sets the avizo_3 of this ProfileMain.

        avizo_3  Předmět notifikačního emailu  při poslání  k podpisu příkazci operace - NM|   # noqa: E501

        :param avizo_3: The avizo_3 of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._avizo_3 = avizo_3

    @property
    def avizo_4(self):
        """Gets the avizo_4 of this ProfileMain.  # noqa: E501

        avizo_4  Předmět notifikačního emailu  při poslání  při poslání k podpisu NM-ŘSFL|   # noqa: E501

        :return: The avizo_4 of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._avizo_4

    @avizo_4.setter
    def avizo_4(self, avizo_4):
        """Sets the avizo_4 of this ProfileMain.

        avizo_4  Předmět notifikačního emailu  při poslání  při poslání k podpisu NM-ŘSFL|   # noqa: E501

        :param avizo_4: The avizo_4 of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._avizo_4 = avizo_4

    @property
    def avizo_5(self):
        """Gets the avizo_5 of this ProfileMain.  # noqa: E501

        avizo_5  Předmět notifikačního emailu  při poslání  ke kontrole Odboru rozpočtu|   # noqa: E501

        :return: The avizo_5 of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._avizo_5

    @avizo_5.setter
    def avizo_5(self, avizo_5):
        """Sets the avizo_5 of this ProfileMain.

        avizo_5  Předmět notifikačního emailu  při poslání  ke kontrole Odboru rozpočtu|   # noqa: E501

        :param avizo_5: The avizo_5 of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._avizo_5 = avizo_5

    @property
    def avizo_6(self):
        """Gets the avizo_6 of this ProfileMain.  # noqa: E501

        avizo_6  Předmět notifikačního emailu  při poslání  k Odboru rozpočtu - přidělení právníkovi|   # noqa: E501

        :return: The avizo_6 of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._avizo_6

    @avizo_6.setter
    def avizo_6(self, avizo_6):
        """Sets the avizo_6 of this ProfileMain.

        avizo_6  Předmět notifikačního emailu  při poslání  k Odboru rozpočtu - přidělení právníkovi|   # noqa: E501

        :param avizo_6: The avizo_6 of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._avizo_6 = avizo_6

    @property
    def avizo_7(self):
        """Gets the avizo_7 of this ProfileMain.  # noqa: E501

        avizo_7  Předmět notifikačního emailu  při poslání  ke kontrole Odboru rozpočtu - právnik|   # noqa: E501

        :return: The avizo_7 of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._avizo_7

    @avizo_7.setter
    def avizo_7(self, avizo_7):
        """Sets the avizo_7 of this ProfileMain.

        avizo_7  Předmět notifikačního emailu  při poslání  ke kontrole Odboru rozpočtu - právnik|   # noqa: E501

        :param avizo_7: The avizo_7 of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._avizo_7 = avizo_7

    @property
    def evidence_status_shortcut_list(self):
        """Gets the evidence_status_shortcut_list of this ProfileMain.  # noqa: E501

        list_of_evidence_status_shortcut  Seznam stavů pro evidenční list zkratka|   # noqa: E501

        :return: The evidence_status_shortcut_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._evidence_status_shortcut_list

    @evidence_status_shortcut_list.setter
    def evidence_status_shortcut_list(self, evidence_status_shortcut_list):
        """Sets the evidence_status_shortcut_list of this ProfileMain.

        list_of_evidence_status_shortcut  Seznam stavů pro evidenční list zkratka|   # noqa: E501

        :param evidence_status_shortcut_list: The evidence_status_shortcut_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._evidence_status_shortcut_list = evidence_status_shortcut_list

    @property
    def evidence_status_list(self):
        """Gets the evidence_status_list of this ProfileMain.  # noqa: E501

        list_of_evidence_status  Seznam stavů pro evidenční list plný text|   # noqa: E501

        :return: The evidence_status_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._evidence_status_list

    @evidence_status_list.setter
    def evidence_status_list(self, evidence_status_list):
        """Sets the evidence_status_list of this ProfileMain.

        list_of_evidence_status  Seznam stavů pro evidenční list plný text|   # noqa: E501

        :param evidence_status_list: The evidence_status_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._evidence_status_list = evidence_status_list

    @property
    def cover_status_shortcut_list(self):
        """Gets the cover_status_shortcut_list of this ProfileMain.  # noqa: E501

        list_of_cover_status_shortcut  Seznam stavu pro kryci list zkratka|   # noqa: E501

        :return: The cover_status_shortcut_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._cover_status_shortcut_list

    @cover_status_shortcut_list.setter
    def cover_status_shortcut_list(self, cover_status_shortcut_list):
        """Sets the cover_status_shortcut_list of this ProfileMain.

        list_of_cover_status_shortcut  Seznam stavu pro kryci list zkratka|   # noqa: E501

        :param cover_status_shortcut_list: The cover_status_shortcut_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._cover_status_shortcut_list = cover_status_shortcut_list

    @property
    def cover_status_list(self):
        """Gets the cover_status_list of this ProfileMain.  # noqa: E501

        list_of_cover_status  Seznam stavu pro kryci list plný text|   # noqa: E501

        :return: The cover_status_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._cover_status_list

    @cover_status_list.setter
    def cover_status_list(self, cover_status_list):
        """Sets the cover_status_list of this ProfileMain.

        list_of_cover_status  Seznam stavu pro kryci list plný text|   # noqa: E501

        :param cover_status_list: The cover_status_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._cover_status_list = cover_status_list

    @property
    def fields_to_log_list(self):
        """Gets the fields_to_log_list of this ProfileMain.  # noqa: E501

        fields2Log    Seznam polí, jejichž hodnoty se mají logovat při uložení Evidenčního listu|   # noqa: E501

        :return: The fields_to_log_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._fields_to_log_list

    @fields_to_log_list.setter
    def fields_to_log_list(self, fields_to_log_list):
        """Sets the fields_to_log_list of this ProfileMain.

        fields2Log    Seznam polí, jejichž hodnoty se mají logovat při uložení Evidenčního listu|   # noqa: E501

        :param fields_to_log_list: The fields_to_log_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._fields_to_log_list = fields_to_log_list

    @property
    def bcc_list(self):
        """Gets the bcc_list of this ProfileMain.  # noqa: E501

        BlindCopy to notification  # noqa: E501

        :return: The bcc_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._bcc_list

    @bcc_list.setter
    def bcc_list(self, bcc_list):
        """Sets the bcc_list of this ProfileMain.

        BlindCopy to notification  # noqa: E501

        :param bcc_list: The bcc_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._bcc_list = bcc_list

    @property
    def budget_department_head(self):
        """Gets the budget_department_head of this ProfileMain.  # noqa: E501

        budget_department_head  Ředitel OR (zobrazení) - slouží pro zobrazení, kdo je ředitel OR. Osoba v tomto # # poli uvidí souhrný pohled všech listů. |   # noqa: E501

        :return: The budget_department_head of this ProfileMain.  # noqa: E501
        :rtype: str
        """
        return self._budget_department_head

    @budget_department_head.setter
    def budget_department_head(self, budget_department_head):
        """Sets the budget_department_head of this ProfileMain.

        budget_department_head  Ředitel OR (zobrazení) - slouží pro zobrazení, kdo je ředitel OR. Osoba v tomto # # poli uvidí souhrný pohled všech listů. |   # noqa: E501

        :param budget_department_head: The budget_department_head of this ProfileMain.  # noqa: E501
        :type: str
        """

        self._budget_department_head = budget_department_head

    @property
    def alpha_help_path_list(self):
        """Gets the alpha_help_path_list of this ProfileMain.  # noqa: E501

        alpha_help_path  Odkaz na nápovědu na serveru Alpha  # noqa: E501

        :return: The alpha_help_path_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._alpha_help_path_list

    @alpha_help_path_list.setter
    def alpha_help_path_list(self, alpha_help_path_list):
        """Sets the alpha_help_path_list of this ProfileMain.

        alpha_help_path  Odkaz na nápovědu na serveru Alpha  # noqa: E501

        :param alpha_help_path_list: The alpha_help_path_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._alpha_help_path_list = alpha_help_path_list

    @property
    def ghoul_help_path_list(self):
        """Gets the ghoul_help_path_list of this ProfileMain.  # noqa: E501

        ghoul_help_path  Odkaz na nápovědu na serveru Ghoul  # noqa: E501

        :return: The ghoul_help_path_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._ghoul_help_path_list

    @ghoul_help_path_list.setter
    def ghoul_help_path_list(self, ghoul_help_path_list):
        """Sets the ghoul_help_path_list of this ProfileMain.

        ghoul_help_path  Odkaz na nápovědu na serveru Ghoul  # noqa: E501

        :param ghoul_help_path_list: The ghoul_help_path_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._ghoul_help_path_list = ghoul_help_path_list

    @property
    def profile_db_pub_list(self):
        """Gets the profile_db_pub_list of this ProfileMain.  # noqa: E501

        Profile_DB_Pub  ContentDB  # noqa: E501

        :return: The profile_db_pub_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._profile_db_pub_list

    @profile_db_pub_list.setter
    def profile_db_pub_list(self, profile_db_pub_list):
        """Sets the profile_db_pub_list of this ProfileMain.

        Profile_DB_Pub  ContentDB  # noqa: E501

        :param profile_db_pub_list: The profile_db_pub_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._profile_db_pub_list = profile_db_pub_list

    @property
    def info_db_alpha_list(self):
        """Gets the info_db_alpha_list of this ProfileMain.  # noqa: E501

        Info_DB_Alpha  InfoDB - Alpha  # noqa: E501

        :return: The info_db_alpha_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._info_db_alpha_list

    @info_db_alpha_list.setter
    def info_db_alpha_list(self, info_db_alpha_list):
        """Sets the info_db_alpha_list of this ProfileMain.

        Info_DB_Alpha  InfoDB - Alpha  # noqa: E501

        :param info_db_alpha_list: The info_db_alpha_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._info_db_alpha_list = info_db_alpha_list

    @property
    def info_db_ghoul_list(self):
        """Gets the info_db_ghoul_list of this ProfileMain.  # noqa: E501

        Info_DB_Ghoul  InfoDB - Ghoul  # noqa: E501

        :return: The info_db_ghoul_list of this ProfileMain.  # noqa: E501
        :rtype: list[str]
        """
        return self._info_db_ghoul_list

    @info_db_ghoul_list.setter
    def info_db_ghoul_list(self, info_db_ghoul_list):
        """Sets the info_db_ghoul_list of this ProfileMain.

        Info_DB_Ghoul  InfoDB - Ghoul  # noqa: E501

        :param info_db_ghoul_list: The info_db_ghoul_list of this ProfileMain.  # noqa: E501
        :type: list[str]
        """

        self._info_db_ghoul_list = info_db_ghoul_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProfileMain, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProfileMain):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaymentEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domino': 'DominoCommons',
        'container_id': 'str',
        'parent_id': 'str',
        'parent_uuid': 'str',
        'department': 'str',
        'contract_type': 'str',
        'description': 'str',
        'bank_account': 'str',
        'sum': 'float',
        'budget_category': 'str',
        'startdate': 'date',
        'enddate': 'date',
        'isprofin': 'str',
        'purpose': 'str',
        'source': 'str'
    }

    attribute_map = {
        'domino': 'domino',
        'container_id': 'container_id',
        'parent_id': 'parent_id',
        'parent_uuid': 'parent_uuid',
        'department': 'department',
        'contract_type': 'contract_type',
        'description': 'description',
        'bank_account': 'bank_account',
        'sum': 'sum',
        'budget_category': 'budget_category',
        'startdate': 'startdate',
        'enddate': 'enddate',
        'isprofin': 'isprofin',
        'purpose': 'purpose',
        'source': 'source'
    }

    def __init__(self, domino=None, container_id=None, parent_id=None, parent_uuid=None, department=None, contract_type=None, description=None, bank_account=None, sum=None, budget_category=None, startdate=None, enddate=None, isprofin=None, purpose=None, source=None):  # noqa: E501
        """PaymentEvent - a model defined in Swagger"""  # noqa: E501
        self._domino = None
        self._container_id = None
        self._parent_id = None
        self._parent_uuid = None
        self._department = None
        self._contract_type = None
        self._description = None
        self._bank_account = None
        self._sum = None
        self._budget_category = None
        self._startdate = None
        self._enddate = None
        self._isprofin = None
        self._purpose = None
        self._source = None
        self.discriminator = None
        if domino is not None:
            self.domino = domino
        if container_id is not None:
            self.container_id = container_id
        if parent_id is not None:
            self.parent_id = parent_id
        if parent_uuid is not None:
            self.parent_uuid = parent_uuid
        if department is not None:
            self.department = department
        if contract_type is not None:
            self.contract_type = contract_type
        if description is not None:
            self.description = description
        if bank_account is not None:
            self.bank_account = bank_account
        if sum is not None:
            self.sum = sum
        if budget_category is not None:
            self.budget_category = budget_category
        if startdate is not None:
            self.startdate = startdate
        if enddate is not None:
            self.enddate = enddate
        if isprofin is not None:
            self.isprofin = isprofin
        if purpose is not None:
            self.purpose = purpose
        if source is not None:
            self.source = source

    @property
    def domino(self):
        """Gets the domino of this PaymentEvent.  # noqa: E501


        :return: The domino of this PaymentEvent.  # noqa: E501
        :rtype: DominoCommons
        """
        return self._domino

    @domino.setter
    def domino(self, domino):
        """Sets the domino of this PaymentEvent.


        :param domino: The domino of this PaymentEvent.  # noqa: E501
        :type: DominoCommons
        """

        self._domino = domino

    @property
    def container_id(self):
        """Gets the container_id of this PaymentEvent.  # noqa: E501

        UUID kontejneru, kam dokument patří  # noqa: E501

        :return: The container_id of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this PaymentEvent.

        UUID kontejneru, kam dokument patří  # noqa: E501

        :param container_id: The container_id of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def parent_id(self):
        """Gets the parent_id of this PaymentEvent.  # noqa: E501

        UNID rodičovského dokument (evidenčního listu)  # noqa: E501

        :return: The parent_id of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this PaymentEvent.

        UNID rodičovského dokument (evidenčního listu)  # noqa: E501

        :param parent_id: The parent_id of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def parent_uuid(self):
        """Gets the parent_uuid of this PaymentEvent.  # noqa: E501

        UUID identifikátor rodičovského dokumentu  # noqa: E501

        :return: The parent_uuid of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._parent_uuid

    @parent_uuid.setter
    def parent_uuid(self, parent_uuid):
        """Sets the parent_uuid of this PaymentEvent.

        UUID identifikátor rodičovského dokumentu  # noqa: E501

        :param parent_uuid: The parent_uuid of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._parent_uuid = parent_uuid

    @property
    def department(self):
        """Gets the department of this PaymentEvent.  # noqa: E501


        :return: The department of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._department

    @department.setter
    def department(self, department):
        """Sets the department of this PaymentEvent.


        :param department: The department of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._department = department

    @property
    def contract_type(self):
        """Gets the contract_type of this PaymentEvent.  # noqa: E501


        :return: The contract_type of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._contract_type

    @contract_type.setter
    def contract_type(self, contract_type):
        """Sets the contract_type of this PaymentEvent.


        :param contract_type: The contract_type of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._contract_type = contract_type

    @property
    def description(self):
        """Gets the description of this PaymentEvent.  # noqa: E501

        item_description - popis  # noqa: E501

        :return: The description of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentEvent.

        item_description - popis  # noqa: E501

        :param description: The description of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def bank_account(self):
        """Gets the bank_account of this PaymentEvent.  # noqa: E501

        item_bank_account - financování z účtu  # noqa: E501

        :return: The bank_account of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._bank_account

    @bank_account.setter
    def bank_account(self, bank_account):
        """Sets the bank_account of this PaymentEvent.

        item_bank_account - financování z účtu  # noqa: E501

        :param bank_account: The bank_account of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._bank_account = bank_account

    @property
    def sum(self):
        """Gets the sum of this PaymentEvent.  # noqa: E501

        item_sum - cena celkem v Kč vč. DPH  # noqa: E501

        :return: The sum of this PaymentEvent.  # noqa: E501
        :rtype: float
        """
        return self._sum

    @sum.setter
    def sum(self, sum):
        """Sets the sum of this PaymentEvent.

        item_sum - cena celkem v Kč vč. DPH  # noqa: E501

        :param sum: The sum of this PaymentEvent.  # noqa: E501
        :type: float
        """

        self._sum = sum

    @property
    def budget_category(self):
        """Gets the budget_category of this PaymentEvent.  # noqa: E501

        item_budget_category - rozpočtové zařazení  # noqa: E501

        :return: The budget_category of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._budget_category

    @budget_category.setter
    def budget_category(self, budget_category):
        """Sets the budget_category of this PaymentEvent.

        item_budget_category - rozpočtové zařazení  # noqa: E501

        :param budget_category: The budget_category of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._budget_category = budget_category

    @property
    def startdate(self):
        """Gets the startdate of this PaymentEvent.  # noqa: E501

        item_startdate - počátek  # noqa: E501

        :return: The startdate of this PaymentEvent.  # noqa: E501
        :rtype: date
        """
        return self._startdate

    @startdate.setter
    def startdate(self, startdate):
        """Sets the startdate of this PaymentEvent.

        item_startdate - počátek  # noqa: E501

        :param startdate: The startdate of this PaymentEvent.  # noqa: E501
        :type: date
        """

        self._startdate = startdate

    @property
    def enddate(self):
        """Gets the enddate of this PaymentEvent.  # noqa: E501

        item_finishdate - ukončení  # noqa: E501

        :return: The enddate of this PaymentEvent.  # noqa: E501
        :rtype: date
        """
        return self._enddate

    @enddate.setter
    def enddate(self, enddate):
        """Sets the enddate of this PaymentEvent.

        item_finishdate - ukončení  # noqa: E501

        :param enddate: The enddate of this PaymentEvent.  # noqa: E501
        :type: date
        """

        self._enddate = enddate

    @property
    def isprofin(self):
        """Gets the isprofin of this PaymentEvent.  # noqa: E501

        item_isprofin - ISPROFIN/Projekt  # noqa: E501

        :return: The isprofin of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._isprofin

    @isprofin.setter
    def isprofin(self, isprofin):
        """Sets the isprofin of this PaymentEvent.

        item_isprofin - ISPROFIN/Projekt  # noqa: E501

        :param isprofin: The isprofin of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._isprofin = isprofin

    @property
    def purpose(self):
        """Gets the purpose of this PaymentEvent.  # noqa: E501

        item_purpose - účel  # noqa: E501

        :return: The purpose of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """Sets the purpose of this PaymentEvent.

        item_purpose - účel  # noqa: E501

        :param purpose: The purpose of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._purpose = purpose

    @property
    def source(self):
        """Gets the source of this PaymentEvent.  # noqa: E501

        item_source - zdroj  # noqa: E501

        :return: The source of this PaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this PaymentEvent.

        item_source - zdroj  # noqa: E501

        :param source: The source of this PaymentEvent.  # noqa: E501
        :type: str
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentAttachmentEntry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'title': 'str',
        'creator': 'str',
        'date_uploaded': 'datetime',
        'attachment_type': 'str',
        'attachment_subtype': 'str',
        'mime_type': 'str',
        'size': 'int',
        'container_id': 'str',
        'document_id': 'str',
        'identifier': 'str',
        'system_authors': 'list[str]',
        'system_readers': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'title': 'title',
        'creator': 'creator',
        'date_uploaded': 'date_uploaded',
        'attachment_type': 'attachment_type',
        'attachment_subtype': 'attachment_subtype',
        'mime_type': 'mime_type',
        'size': 'size',
        'container_id': 'container_id',
        'document_id': 'document_id',
        'identifier': 'identifier',
        'system_authors': 'system_authors',
        'system_readers': 'system_readers'
    }

    def __init__(self, name=None, title=None, creator=None, date_uploaded=None, attachment_type=None, attachment_subtype=None, mime_type=None, size=None, container_id=None, document_id=None, identifier=None, system_authors=None, system_readers=None):  # noqa: E501
        """DocumentAttachmentEntry - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._title = None
        self._creator = None
        self._date_uploaded = None
        self._attachment_type = None
        self._attachment_subtype = None
        self._mime_type = None
        self._size = None
        self._container_id = None
        self._document_id = None
        self._identifier = None
        self._system_authors = None
        self._system_readers = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if title is not None:
            self.title = title
        if creator is not None:
            self.creator = creator
        if date_uploaded is not None:
            self.date_uploaded = date_uploaded
        if attachment_type is not None:
            self.attachment_type = attachment_type
        if attachment_subtype is not None:
            self.attachment_subtype = attachment_subtype
        if mime_type is not None:
            self.mime_type = mime_type
        if size is not None:
            self.size = size
        if container_id is not None:
            self.container_id = container_id
        if document_id is not None:
            self.document_id = document_id
        if identifier is not None:
            self.identifier = identifier
        if system_authors is not None:
            self.system_authors = system_authors
        if system_readers is not None:
            self.system_readers = system_readers

    @property
    def name(self):
        """Gets the name of this DocumentAttachmentEntry.  # noqa: E501

        Attachment name for display  # noqa: E501

        :return: The name of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DocumentAttachmentEntry.

        Attachment name for display  # noqa: E501

        :param name: The name of this DocumentAttachmentEntry.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def title(self):
        """Gets the title of this DocumentAttachmentEntry.  # noqa: E501

        Attachment title for display  # noqa: E501

        :return: The title of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this DocumentAttachmentEntry.

        Attachment title for display  # noqa: E501

        :param title: The title of this DocumentAttachmentEntry.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def creator(self):
        """Gets the creator of this DocumentAttachmentEntry.  # noqa: E501

        Osoba, která uploadovala přílohu  # noqa: E501

        :return: The creator of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: str
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this DocumentAttachmentEntry.

        Osoba, která uploadovala přílohu  # noqa: E501

        :param creator: The creator of this DocumentAttachmentEntry.  # noqa: E501
        :type: str
        """

        self._creator = creator

    @property
    def date_uploaded(self):
        """Gets the date_uploaded of this DocumentAttachmentEntry.  # noqa: E501

        Datum uploadu přílohy  # noqa: E501

        :return: The date_uploaded of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._date_uploaded

    @date_uploaded.setter
    def date_uploaded(self, date_uploaded):
        """Sets the date_uploaded of this DocumentAttachmentEntry.

        Datum uploadu přílohy  # noqa: E501

        :param date_uploaded: The date_uploaded of this DocumentAttachmentEntry.  # noqa: E501
        :type: datetime
        """

        self._date_uploaded = date_uploaded

    @property
    def attachment_type(self):
        """Gets the attachment_type of this DocumentAttachmentEntry.  # noqa: E501

        Typ přílohy - z číselníku typů  # noqa: E501

        :return: The attachment_type of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """Sets the attachment_type of this DocumentAttachmentEntry.

        Typ přílohy - z číselníku typů  # noqa: E501

        :param attachment_type: The attachment_type of this DocumentAttachmentEntry.  # noqa: E501
        :type: str
        """

        self._attachment_type = attachment_type

    @property
    def attachment_subtype(self):
        """Gets the attachment_subtype of this DocumentAttachmentEntry.  # noqa: E501

        Typ přílohy - z číselníku typů  # noqa: E501

        :return: The attachment_subtype of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: str
        """
        return self._attachment_subtype

    @attachment_subtype.setter
    def attachment_subtype(self, attachment_subtype):
        """Sets the attachment_subtype of this DocumentAttachmentEntry.

        Typ přílohy - z číselníku typů  # noqa: E501

        :param attachment_subtype: The attachment_subtype of this DocumentAttachmentEntry.  # noqa: E501
        :type: str
        """

        self._attachment_subtype = attachment_subtype

    @property
    def mime_type(self):
        """Gets the mime_type of this DocumentAttachmentEntry.  # noqa: E501

        Attachment mime type  # noqa: E501

        :return: The mime_type of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this DocumentAttachmentEntry.

        Attachment mime type  # noqa: E501

        :param mime_type: The mime_type of this DocumentAttachmentEntry.  # noqa: E501
        :type: str
        """

        self._mime_type = mime_type

    @property
    def size(self):
        """Gets the size of this DocumentAttachmentEntry.  # noqa: E501

        File size  # noqa: E501

        :return: The size of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this DocumentAttachmentEntry.

        File size  # noqa: E501

        :param size: The size of this DocumentAttachmentEntry.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def container_id(self):
        """Gets the container_id of this DocumentAttachmentEntry.  # noqa: E501

        Container unique identifier  # noqa: E501

        :return: The container_id of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this DocumentAttachmentEntry.

        Container unique identifier  # noqa: E501

        :param container_id: The container_id of this DocumentAttachmentEntry.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def document_id(self):
        """Gets the document_id of this DocumentAttachmentEntry.  # noqa: E501

        Source document unique identifier  # noqa: E501

        :return: The document_id of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this DocumentAttachmentEntry.

        Source document unique identifier  # noqa: E501

        :param document_id: The document_id of this DocumentAttachmentEntry.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def identifier(self):
        """Gets the identifier of this DocumentAttachmentEntry.  # noqa: E501

        Attachment unique identifier  # noqa: E501

        :return: The identifier of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this DocumentAttachmentEntry.

        Attachment unique identifier  # noqa: E501

        :param identifier: The identifier of this DocumentAttachmentEntry.  # noqa: E501
        :type: str
        """

        self._identifier = identifier

    @property
    def system_authors(self):
        """Gets the system_authors of this DocumentAttachmentEntry.  # noqa: E501

        SystemAuthors  - seznam osob a útvarů oprávněných zapisovat do dokumentu  # noqa: E501

        :return: The system_authors of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: list[str]
        """
        return self._system_authors

    @system_authors.setter
    def system_authors(self, system_authors):
        """Sets the system_authors of this DocumentAttachmentEntry.

        SystemAuthors  - seznam osob a útvarů oprávněných zapisovat do dokumentu  # noqa: E501

        :param system_authors: The system_authors of this DocumentAttachmentEntry.  # noqa: E501
        :type: list[str]
        """

        self._system_authors = system_authors

    @property
    def system_readers(self):
        """Gets the system_readers of this DocumentAttachmentEntry.  # noqa: E501

        SystemReaders - seznam osob a útvarů číst dokument  # noqa: E501

        :return: The system_readers of this DocumentAttachmentEntry.  # noqa: E501
        :rtype: list[str]
        """
        return self._system_readers

    @system_readers.setter
    def system_readers(self, system_readers):
        """Sets the system_readers of this DocumentAttachmentEntry.

        SystemReaders - seznam osob a útvarů číst dokument  # noqa: E501

        :param system_readers: The system_readers of this DocumentAttachmentEntry.  # noqa: E501
        :type: list[str]
        """

        self._system_readers = system_readers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentAttachmentEntry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentAttachmentEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import esmlouvy_connector
from esmlouvy_connector.api.public_api import PublicApi  # noqa: E501
from esmlouvy_connector.rest import ApiException


class TestPublicApi(unittest.TestCase):
    """PublicApi unit test stubs"""

    def setUp(self):
        self.api = PublicApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_budget_category(self):
        """Test case for delete_budget_category

        odstraní položku rozpočtového zařazení s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_container(self):
        """Test case for delete_container

        odstraní dokumentový kontejner s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_cover(self):
        """Test case for delete_cover

        odstraní krycí list s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_payment_event(self):
        """Test case for delete_payment_event

        odstraní položku platebního kalenáře s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_registration(self):
        """Test case for delete_registration

        odstraní evidenční list s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_delete_standpoint(self):
        """Test case for delete_standpoint

        odstraní stanovisko s daným identifikátorem (cruD)  # noqa: E501
        """
        pass

    def test_get_budget_category(self):
        """Test case for get_budget_category

        vrací položku rozpočtového zařazení s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_budget_category_list(self):
        """Test case for get_budget_category_list

        vrací seznam rozpočtových zařazení  # noqa: E501
        """
        pass

    def test_get_budget_category_list_by_dept(self):
        """Test case for get_budget_category_list_by_dept

        vrací všechna rozpočtová opatření pro útvar  # noqa: E501
        """
        pass

    def test_get_container(self):
        """Test case for get_container

        vrací dokumentový kontejner s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_container_content(self):
        """Test case for get_container_content

        vrací obsah kontejneru s daným identifikátorem  # noqa: E501
        """
        pass

    def test_get_container_list(self):
        """Test case for get_container_list

        vrací seznam dokumentových kontejnerů  # noqa: E501
        """
        pass

    def test_get_cover(self):
        """Test case for get_cover

        vrací krycí list s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_cover_list(self):
        """Test case for get_cover_list

        vrací seznam kycích listů  # noqa: E501
        """
        pass

    def test_get_cover_list_container(self):
        """Test case for get_cover_list_container

        vrací seznam kycích listů v kontejneru  # noqa: E501
        """
        pass

    def test_get_payment_event(self):
        """Test case for get_payment_event

        vrací položku platebního kalenáře s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_payment_event_list(self):
        """Test case for get_payment_event_list

        vrací seznam položek platebního kalendáře  # noqa: E501
        """
        pass

    def test_get_payment_event_list_parent(self):
        """Test case for get_payment_event_list_parent

        vrací seznam položek platebního kalendáře pro nadřazený dokument  # noqa: E501
        """
        pass

    def test_get_registration(self):
        """Test case for get_registration

        vrací evidenční list s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_registration_list(self):
        """Test case for get_registration_list

        vrací seznam registračních listů  # noqa: E501
        """
        pass

    def test_get_registration_list_container(self):
        """Test case for get_registration_list_container

        vrací seznam registračních listů v kontejneru  # noqa: E501
        """
        pass

    def test_get_standpoint(self):
        """Test case for get_standpoint

        vrací stanovisko s daným identifikátorem (cRud)  # noqa: E501
        """
        pass

    def test_get_standpoint_list(self):
        """Test case for get_standpoint_list

        vrací seznam stanovisek  # noqa: E501
        """
        pass

    def test_get_standpoint_list_container(self):
        """Test case for get_standpoint_list_container

        vrací seznam stanovisek v kontejneru  # noqa: E501
        """
        pass

    def test_get_standpoint_list_parent(self):
        """Test case for get_standpoint_list_parent

        vrací seznam stanovisek pro nadřízený dokument  # noqa: E501
        """
        pass

    def test_post_budget_category(self):
        """Test case for post_budget_category

        vytvoří novou položku rozpočtového zařazení (Crud)  # noqa: E501
        """
        pass

    def test_post_container(self):
        """Test case for post_container

        vytvoří nový dokumentový kontejner (Crud)  # noqa: E501
        """
        pass

    def test_post_cover(self):
        """Test case for post_cover

        vytvoří nový krycí list (Crud)  # noqa: E501
        """
        pass

    def test_post_payment_event(self):
        """Test case for post_payment_event

        vytvoří novou položku platebního kalendáře (Crud)  # noqa: E501
        """
        pass

    def test_post_registration(self):
        """Test case for post_registration

        vytvoří nový evidenční list (Crud)  # noqa: E501
        """
        pass

    def test_post_standpoint(self):
        """Test case for post_standpoint

        vytvoří nové stanovisko (Crud)  # noqa: E501
        """
        pass

    def test_put_budget_category(self):
        """Test case for put_budget_category

        aktualizuje položku rozpočtového zařazení s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_container(self):
        """Test case for put_container

        aktualizuje dokumentový kontejner s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_cover(self):
        """Test case for put_cover

        aktualizuje krycí list s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_payment_event(self):
        """Test case for put_payment_event

        aktualizuje položku platebního kalenáře s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_registration(self):
        """Test case for put_registration

        aktualizuje evidenční list s daným identifikátorem (crUd)  # noqa: E501
        """
        pass

    def test_put_standpoint(self):
        """Test case for put_standpoint

        aktualizuje stanovisko s daným identifikátorem (crUd)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DominoCommons(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'pid': 'str',
        'unid': 'str',
        'deleted': 'bool',
        'created': 'str',
        'modified': 'str',
        'authors': 'list[str]',
        'readers': 'list[str]',
        'form': 'str'
    }

    attribute_map = {
        'id': 'id',
        'pid': 'pid',
        'unid': 'unid',
        'deleted': 'deleted',
        'created': 'created',
        'modified': 'modified',
        'authors': 'authors',
        'readers': 'readers',
        'form': 'form'
    }

    def __init__(self, id=None, pid=None, unid=None, deleted=None, created=None, modified=None, authors=None, readers=None, form=None):  # noqa: E501
        """DominoCommons - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._pid = None
        self._unid = None
        self._deleted = None
        self._created = None
        self._modified = None
        self._authors = None
        self._readers = None
        self._form = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if pid is not None:
            self.pid = pid
        if unid is not None:
            self.unid = unid
        if deleted is not None:
            self.deleted = deleted
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified
        if authors is not None:
            self.authors = authors
        if readers is not None:
            self.readers = readers
        if form is not None:
            self.form = form

    @property
    def id(self):
        """Gets the id of this DominoCommons.  # noqa: E501

        UUID dokumentu (bude generován místo PID)  # noqa: E501

        :return: The id of this DominoCommons.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DominoCommons.

        UUID dokumentu (bude generován místo PID)  # noqa: E501

        :param id: The id of this DominoCommons.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def pid(self):
        """Gets the pid of this DominoCommons.  # noqa: E501

        Jednoznačný identifikátor generovaný v databázi Domino  # noqa: E501

        :return: The pid of this DominoCommons.  # noqa: E501
        :rtype: str
        """
        return self._pid

    @pid.setter
    def pid(self, pid):
        """Sets the pid of this DominoCommons.

        Jednoznačný identifikátor generovaný v databázi Domino  # noqa: E501

        :param pid: The pid of this DominoCommons.  # noqa: E501
        :type: str
        """

        self._pid = pid

    @property
    def unid(self):
        """Gets the unid of this DominoCommons.  # noqa: E501

        Jednoznačný identifikátor dokumentu generovaný serverem Domino  # noqa: E501

        :return: The unid of this DominoCommons.  # noqa: E501
        :rtype: str
        """
        return self._unid

    @unid.setter
    def unid(self, unid):
        """Sets the unid of this DominoCommons.

        Jednoznačný identifikátor dokumentu generovaný serverem Domino  # noqa: E501

        :param unid: The unid of this DominoCommons.  # noqa: E501
        :type: str
        """

        self._unid = unid

    @property
    def deleted(self):
        """Gets the deleted of this DominoCommons.  # noqa: E501

        Dokument byl odstraněn  # noqa: E501

        :return: The deleted of this DominoCommons.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this DominoCommons.

        Dokument byl odstraněn  # noqa: E501

        :param deleted: The deleted of this DominoCommons.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def created(self):
        """Gets the created of this DominoCommons.  # noqa: E501

        datum a čas vytvoření dokumentu  # noqa: E501

        :return: The created of this DominoCommons.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this DominoCommons.

        datum a čas vytvoření dokumentu  # noqa: E501

        :param created: The created of this DominoCommons.  # noqa: E501
        :type: str
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this DominoCommons.  # noqa: E501

        datum a čas poslední úptavy dokumentu  # noqa: E501

        :return: The modified of this DominoCommons.  # noqa: E501
        :rtype: str
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this DominoCommons.

        datum a čas poslední úptavy dokumentu  # noqa: E501

        :param modified: The modified of this DominoCommons.  # noqa: E501
        :type: str
        """

        self._modified = modified

    @property
    def authors(self):
        """Gets the authors of this DominoCommons.  # noqa: E501

        seznam oprávněných autorů dokumentu  # noqa: E501

        :return: The authors of this DominoCommons.  # noqa: E501
        :rtype: list[str]
        """
        return self._authors

    @authors.setter
    def authors(self, authors):
        """Sets the authors of this DominoCommons.

        seznam oprávněných autorů dokumentu  # noqa: E501

        :param authors: The authors of this DominoCommons.  # noqa: E501
        :type: list[str]
        """

        self._authors = authors

    @property
    def readers(self):
        """Gets the readers of this DominoCommons.  # noqa: E501

        seznam oprávněných ačtenářů dokumentu  # noqa: E501

        :return: The readers of this DominoCommons.  # noqa: E501
        :rtype: list[str]
        """
        return self._readers

    @readers.setter
    def readers(self, readers):
        """Sets the readers of this DominoCommons.

        seznam oprávněných ačtenářů dokumentu  # noqa: E501

        :param readers: The readers of this DominoCommons.  # noqa: E501
        :type: list[str]
        """

        self._readers = readers

    @property
    def form(self):
        """Gets the form of this DominoCommons.  # noqa: E501

        formulář Notes  # noqa: E501

        :return: The form of this DominoCommons.  # noqa: E501
        :rtype: str
        """
        return self._form

    @form.setter
    def form(self, form):
        """Sets the form of this DominoCommons.

        formulář Notes  # noqa: E501

        :param form: The form of this DominoCommons.  # noqa: E501
        :type: str
        """

        self._form = form

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DominoCommons, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DominoCommons):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BaseDominoDocument(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domino': 'DominoCommons',
        'hidden': 'DocumentHidden',
        'acl': 'DocumentAcl',
        'header': 'DocumentHeader'
    }

    attribute_map = {
        'domino': 'domino',
        'hidden': 'hidden',
        'acl': 'acl',
        'header': 'header'
    }

    def __init__(self, domino=None, hidden=None, acl=None, header=None):  # noqa: E501
        """BaseDominoDocument - a model defined in Swagger"""  # noqa: E501
        self._domino = None
        self._hidden = None
        self._acl = None
        self._header = None
        self.discriminator = None
        if domino is not None:
            self.domino = domino
        if hidden is not None:
            self.hidden = hidden
        if acl is not None:
            self.acl = acl
        if header is not None:
            self.header = header

    @property
    def domino(self):
        """Gets the domino of this BaseDominoDocument.  # noqa: E501


        :return: The domino of this BaseDominoDocument.  # noqa: E501
        :rtype: DominoCommons
        """
        return self._domino

    @domino.setter
    def domino(self, domino):
        """Sets the domino of this BaseDominoDocument.


        :param domino: The domino of this BaseDominoDocument.  # noqa: E501
        :type: DominoCommons
        """

        self._domino = domino

    @property
    def hidden(self):
        """Gets the hidden of this BaseDominoDocument.  # noqa: E501


        :return: The hidden of this BaseDominoDocument.  # noqa: E501
        :rtype: DocumentHidden
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this BaseDominoDocument.


        :param hidden: The hidden of this BaseDominoDocument.  # noqa: E501
        :type: DocumentHidden
        """

        self._hidden = hidden

    @property
    def acl(self):
        """Gets the acl of this BaseDominoDocument.  # noqa: E501


        :return: The acl of this BaseDominoDocument.  # noqa: E501
        :rtype: DocumentAcl
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this BaseDominoDocument.


        :param acl: The acl of this BaseDominoDocument.  # noqa: E501
        :type: DocumentAcl
        """

        self._acl = acl

    @property
    def header(self):
        """Gets the header of this BaseDominoDocument.  # noqa: E501


        :return: The header of this BaseDominoDocument.  # noqa: E501
        :rtype: DocumentHeader
        """
        return self._header

    @header.setter
    def header(self, header):
        """Sets the header of this BaseDominoDocument.


        :param header: The header of this BaseDominoDocument.  # noqa: E501
        :type: DocumentHeader
        """

        self._header = header

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BaseDominoDocument, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BaseDominoDocument):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CoverSheet(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'base': 'BaseSheetDocument',
        'contract_type': 'str',
        'identifier_subcontract': 'str',
        'date_contract_submitted': 'date',
        'contractor': 'Company',
        'choice': 'Choice',
        'subcontract_note': 'str',
        'date_contract': 'date',
        'date_finish_contract': 'date',
        'duration': 'str',
        'payment_period': 'str',
        'date_purge': 'date',
        'contract_value_vat': 'float',
        'contract_value_published': 'str',
        'calendar_value_check': 'int',
        'finance_eu': 'bool',
        'identifier_registration_sheet': 'str',
        'payment_calendar': 'DocumentEntryList',
        'standpoint_list': 'DocumentEntryList',
        'choice_company_ovz_statement': 'str',
        'choice_company_ovz_statement_attachments': 'list[DocumentAttachment]',
        'choice_company_ovz_statement_attachments_old': 'str',
        'draft_contract_attachments': 'list[DocumentAttachment]',
        'draft_contract_attachments_old': 'str',
        'signed_contract_attachments': 'list[DocumentAttachment]',
        'signed_contract_attachments_old': 'str',
        'oldcontract_scan_deliver_later': 'bool'
    }

    attribute_map = {
        'base': 'base',
        'contract_type': 'contract_type',
        'identifier_subcontract': 'identifier_subcontract',
        'date_contract_submitted': 'date_contract_submitted',
        'contractor': 'contractor',
        'choice': 'choice',
        'subcontract_note': 'subcontract_note',
        'date_contract': 'date_contract',
        'date_finish_contract': 'date_finish_contract',
        'duration': 'duration',
        'payment_period': 'payment_period',
        'date_purge': 'date_purge',
        'contract_value_vat': 'contract_value_vat',
        'contract_value_published': 'contract_value_published',
        'calendar_value_check': 'calendar_value_check',
        'finance_eu': 'finance_eu',
        'identifier_registration_sheet': 'identifier_registration_sheet',
        'payment_calendar': 'payment_calendar',
        'standpoint_list': 'standpoint_list',
        'choice_company_ovz_statement': 'choice_company_ovz_statement',
        'choice_company_ovz_statement_attachments': 'choice_company_ovz_statement_attachments',
        'choice_company_ovz_statement_attachments_old': 'choice_company_ovz_statement_attachments_old',
        'draft_contract_attachments': 'draft_contract_attachments',
        'draft_contract_attachments_old': 'draft_contract_attachments_old',
        'signed_contract_attachments': 'signed_contract_attachments',
        'signed_contract_attachments_old': 'signed_contract_attachments_old',
        'oldcontract_scan_deliver_later': 'oldcontract_scan_deliver_later'
    }

    def __init__(self, base=None, contract_type=None, identifier_subcontract=None, date_contract_submitted=None, contractor=None, choice=None, subcontract_note=None, date_contract=None, date_finish_contract=None, duration=None, payment_period=None, date_purge=None, contract_value_vat=None, contract_value_published=None, calendar_value_check=None, finance_eu=None, identifier_registration_sheet=None, payment_calendar=None, standpoint_list=None, choice_company_ovz_statement=None, choice_company_ovz_statement_attachments=None, choice_company_ovz_statement_attachments_old=None, draft_contract_attachments=None, draft_contract_attachments_old=None, signed_contract_attachments=None, signed_contract_attachments_old=None, oldcontract_scan_deliver_later=None):  # noqa: E501
        """CoverSheet - a model defined in Swagger"""  # noqa: E501
        self._base = None
        self._contract_type = None
        self._identifier_subcontract = None
        self._date_contract_submitted = None
        self._contractor = None
        self._choice = None
        self._subcontract_note = None
        self._date_contract = None
        self._date_finish_contract = None
        self._duration = None
        self._payment_period = None
        self._date_purge = None
        self._contract_value_vat = None
        self._contract_value_published = None
        self._calendar_value_check = None
        self._finance_eu = None
        self._identifier_registration_sheet = None
        self._payment_calendar = None
        self._standpoint_list = None
        self._choice_company_ovz_statement = None
        self._choice_company_ovz_statement_attachments = None
        self._choice_company_ovz_statement_attachments_old = None
        self._draft_contract_attachments = None
        self._draft_contract_attachments_old = None
        self._signed_contract_attachments = None
        self._signed_contract_attachments_old = None
        self._oldcontract_scan_deliver_later = None
        self.discriminator = None
        if base is not None:
            self.base = base
        if contract_type is not None:
            self.contract_type = contract_type
        if identifier_subcontract is not None:
            self.identifier_subcontract = identifier_subcontract
        if date_contract_submitted is not None:
            self.date_contract_submitted = date_contract_submitted
        if contractor is not None:
            self.contractor = contractor
        if choice is not None:
            self.choice = choice
        if subcontract_note is not None:
            self.subcontract_note = subcontract_note
        if date_contract is not None:
            self.date_contract = date_contract
        if date_finish_contract is not None:
            self.date_finish_contract = date_finish_contract
        if duration is not None:
            self.duration = duration
        if payment_period is not None:
            self.payment_period = payment_period
        if date_purge is not None:
            self.date_purge = date_purge
        if contract_value_vat is not None:
            self.contract_value_vat = contract_value_vat
        if contract_value_published is not None:
            self.contract_value_published = contract_value_published
        if calendar_value_check is not None:
            self.calendar_value_check = calendar_value_check
        if finance_eu is not None:
            self.finance_eu = finance_eu
        if identifier_registration_sheet is not None:
            self.identifier_registration_sheet = identifier_registration_sheet
        if payment_calendar is not None:
            self.payment_calendar = payment_calendar
        if standpoint_list is not None:
            self.standpoint_list = standpoint_list
        if choice_company_ovz_statement is not None:
            self.choice_company_ovz_statement = choice_company_ovz_statement
        if choice_company_ovz_statement_attachments is not None:
            self.choice_company_ovz_statement_attachments = choice_company_ovz_statement_attachments
        if choice_company_ovz_statement_attachments_old is not None:
            self.choice_company_ovz_statement_attachments_old = choice_company_ovz_statement_attachments_old
        if draft_contract_attachments is not None:
            self.draft_contract_attachments = draft_contract_attachments
        if draft_contract_attachments_old is not None:
            self.draft_contract_attachments_old = draft_contract_attachments_old
        if signed_contract_attachments is not None:
            self.signed_contract_attachments = signed_contract_attachments
        if signed_contract_attachments_old is not None:
            self.signed_contract_attachments_old = signed_contract_attachments_old
        if oldcontract_scan_deliver_later is not None:
            self.oldcontract_scan_deliver_later = oldcontract_scan_deliver_later

    @property
    def base(self):
        """Gets the base of this CoverSheet.  # noqa: E501


        :return: The base of this CoverSheet.  # noqa: E501
        :rtype: BaseSheetDocument
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this CoverSheet.


        :param base: The base of this CoverSheet.  # noqa: E501
        :type: BaseSheetDocument
        """

        self._base = base

    @property
    def contract_type(self):
        """Gets the contract_type of this CoverSheet.  # noqa: E501

        Typ smlouvy (SA, SB, SC, SD, SX)  # noqa: E501

        :return: The contract_type of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._contract_type

    @contract_type.setter
    def contract_type(self, contract_type):
        """Sets the contract_type of this CoverSheet.

        Typ smlouvy (SA, SB, SC, SD, SX)  # noqa: E501

        :param contract_type: The contract_type of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._contract_type = contract_type

    @property
    def identifier_subcontract(self):
        """Gets the identifier_subcontract of this CoverSheet.  # noqa: E501

        identifier_subcontract - Číslo dodatku:  # noqa: E501

        :return: The identifier_subcontract of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._identifier_subcontract

    @identifier_subcontract.setter
    def identifier_subcontract(self, identifier_subcontract):
        """Sets the identifier_subcontract of this CoverSheet.

        identifier_subcontract - Číslo dodatku:  # noqa: E501

        :param identifier_subcontract: The identifier_subcontract of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._identifier_subcontract = identifier_subcontract

    @property
    def date_contract_submitted(self):
        """Gets the date_contract_submitted of this CoverSheet.  # noqa: E501

        date_contract_submitted - Dodatek ze dne (Datum podpisu)  # noqa: E501

        :return: The date_contract_submitted of this CoverSheet.  # noqa: E501
        :rtype: date
        """
        return self._date_contract_submitted

    @date_contract_submitted.setter
    def date_contract_submitted(self, date_contract_submitted):
        """Sets the date_contract_submitted of this CoverSheet.

        date_contract_submitted - Dodatek ze dne (Datum podpisu)  # noqa: E501

        :param date_contract_submitted: The date_contract_submitted of this CoverSheet.  # noqa: E501
        :type: date
        """

        self._date_contract_submitted = date_contract_submitted

    @property
    def contractor(self):
        """Gets the contractor of this CoverSheet.  # noqa: E501


        :return: The contractor of this CoverSheet.  # noqa: E501
        :rtype: Company
        """
        return self._contractor

    @contractor.setter
    def contractor(self, contractor):
        """Sets the contractor of this CoverSheet.


        :param contractor: The contractor of this CoverSheet.  # noqa: E501
        :type: Company
        """

        self._contractor = contractor

    @property
    def choice(self):
        """Gets the choice of this CoverSheet.  # noqa: E501


        :return: The choice of this CoverSheet.  # noqa: E501
        :rtype: Choice
        """
        return self._choice

    @choice.setter
    def choice(self, choice):
        """Sets the choice of this CoverSheet.


        :param choice: The choice of this CoverSheet.  # noqa: E501
        :type: Choice
        """

        self._choice = choice

    @property
    def subcontract_note(self):
        """Gets the subcontract_note of this CoverSheet.  # noqa: E501

        Poznámka ke smlouvě, stručný obsah dodatku (změny oproti smlouvě)  # noqa: E501

        :return: The subcontract_note of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._subcontract_note

    @subcontract_note.setter
    def subcontract_note(self, subcontract_note):
        """Sets the subcontract_note of this CoverSheet.

        Poznámka ke smlouvě, stručný obsah dodatku (změny oproti smlouvě)  # noqa: E501

        :param subcontract_note: The subcontract_note of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._subcontract_note = subcontract_note

    @property
    def date_contract(self):
        """Gets the date_contract of this CoverSheet.  # noqa: E501

        date_contract - Termín uzavření smlouvy  # noqa: E501

        :return: The date_contract of this CoverSheet.  # noqa: E501
        :rtype: date
        """
        return self._date_contract

    @date_contract.setter
    def date_contract(self, date_contract):
        """Sets the date_contract of this CoverSheet.

        date_contract - Termín uzavření smlouvy  # noqa: E501

        :param date_contract: The date_contract of this CoverSheet.  # noqa: E501
        :type: date
        """

        self._date_contract = date_contract

    @property
    def date_finish_contract(self):
        """Gets the date_finish_contract of this CoverSheet.  # noqa: E501

        date_finish_contract - Termín ukončení smlouvy  # noqa: E501

        :return: The date_finish_contract of this CoverSheet.  # noqa: E501
        :rtype: date
        """
        return self._date_finish_contract

    @date_finish_contract.setter
    def date_finish_contract(self, date_finish_contract):
        """Sets the date_finish_contract of this CoverSheet.

        date_finish_contract - Termín ukončení smlouvy  # noqa: E501

        :param date_finish_contract: The date_finish_contract of this CoverSheet.  # noqa: E501
        :type: date
        """

        self._date_finish_contract = date_finish_contract

    @property
    def duration(self):
        """Gets the duration of this CoverSheet.  # noqa: E501

        Duration - Trvání (text)  # noqa: E501

        :return: The duration of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this CoverSheet.

        Duration - Trvání (text)  # noqa: E501

        :param duration: The duration of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._duration = duration

    @property
    def payment_period(self):
        """Gets the payment_period of this CoverSheet.  # noqa: E501

        payment_period - Termín plateb (text), např. čtvrtletně, měsíčně)  # noqa: E501

        :return: The payment_period of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._payment_period

    @payment_period.setter
    def payment_period(self, payment_period):
        """Sets the payment_period of this CoverSheet.

        payment_period - Termín plateb (text), např. čtvrtletně, měsíčně)  # noqa: E501

        :param payment_period: The payment_period of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._payment_period = payment_period

    @property
    def date_purge(self):
        """Gets the date_purge of this CoverSheet.  # noqa: E501

        date_purge - Splatnost  # noqa: E501

        :return: The date_purge of this CoverSheet.  # noqa: E501
        :rtype: date
        """
        return self._date_purge

    @date_purge.setter
    def date_purge(self, date_purge):
        """Sets the date_purge of this CoverSheet.

        date_purge - Splatnost  # noqa: E501

        :param date_purge: The date_purge of this CoverSheet.  # noqa: E501
        :type: date
        """

        self._date_purge = date_purge

    @property
    def contract_value_vat(self):
        """Gets the contract_value_vat of this CoverSheet.  # noqa: E501

        contract_value_tax - Celková částka za smlouvu v Kč vč. DPH  # noqa: E501

        :return: The contract_value_vat of this CoverSheet.  # noqa: E501
        :rtype: float
        """
        return self._contract_value_vat

    @contract_value_vat.setter
    def contract_value_vat(self, contract_value_vat):
        """Sets the contract_value_vat of this CoverSheet.

        contract_value_tax - Celková částka za smlouvu v Kč vč. DPH  # noqa: E501

        :param contract_value_vat: The contract_value_vat of this CoverSheet.  # noqa: E501
        :type: float
        """

        self._contract_value_vat = contract_value_vat

    @property
    def contract_value_published(self):
        """Gets the contract_value_published of this CoverSheet.  # noqa: E501

        contract_value_published - Publikovaná částka za smlouvu Obecný text. Pokud bude tato hodnota vyplněna, bude publikována na webové stránky místo celkové částky za smlouvu    # noqa: E501

        :return: The contract_value_published of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._contract_value_published

    @contract_value_published.setter
    def contract_value_published(self, contract_value_published):
        """Sets the contract_value_published of this CoverSheet.

        contract_value_published - Publikovaná částka za smlouvu Obecný text. Pokud bude tato hodnota vyplněna, bude publikována na webové stránky místo celkové částky za smlouvu    # noqa: E501

        :param contract_value_published: The contract_value_published of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._contract_value_published = contract_value_published

    @property
    def calendar_value_check(self):
        """Gets the calendar_value_check of this CoverSheet.  # noqa: E501

        calendar_value_check - Kontrolní součet z platebního kalendáře  # noqa: E501

        :return: The calendar_value_check of this CoverSheet.  # noqa: E501
        :rtype: int
        """
        return self._calendar_value_check

    @calendar_value_check.setter
    def calendar_value_check(self, calendar_value_check):
        """Sets the calendar_value_check of this CoverSheet.

        calendar_value_check - Kontrolní součet z platebního kalendáře  # noqa: E501

        :param calendar_value_check: The calendar_value_check of this CoverSheet.  # noqa: E501
        :type: int
        """

        self._calendar_value_check = calendar_value_check

    @property
    def finance_eu(self):
        """Gets the finance_eu of this CoverSheet.  # noqa: E501

        Spolufinancovaní EU  # noqa: E501

        :return: The finance_eu of this CoverSheet.  # noqa: E501
        :rtype: bool
        """
        return self._finance_eu

    @finance_eu.setter
    def finance_eu(self, finance_eu):
        """Sets the finance_eu of this CoverSheet.

        Spolufinancovaní EU  # noqa: E501

        :param finance_eu: The finance_eu of this CoverSheet.  # noqa: E501
        :type: bool
        """

        self._finance_eu = finance_eu

    @property
    def identifier_registration_sheet(self):
        """Gets the identifier_registration_sheet of this CoverSheet.  # noqa: E501

        EvidenceNoteUNID, evidence_note_unid - UNID evidenčního listu  # noqa: E501

        :return: The identifier_registration_sheet of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._identifier_registration_sheet

    @identifier_registration_sheet.setter
    def identifier_registration_sheet(self, identifier_registration_sheet):
        """Sets the identifier_registration_sheet of this CoverSheet.

        EvidenceNoteUNID, evidence_note_unid - UNID evidenčního listu  # noqa: E501

        :param identifier_registration_sheet: The identifier_registration_sheet of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._identifier_registration_sheet = identifier_registration_sheet

    @property
    def payment_calendar(self):
        """Gets the payment_calendar of this CoverSheet.  # noqa: E501


        :return: The payment_calendar of this CoverSheet.  # noqa: E501
        :rtype: DocumentEntryList
        """
        return self._payment_calendar

    @payment_calendar.setter
    def payment_calendar(self, payment_calendar):
        """Sets the payment_calendar of this CoverSheet.


        :param payment_calendar: The payment_calendar of this CoverSheet.  # noqa: E501
        :type: DocumentEntryList
        """

        self._payment_calendar = payment_calendar

    @property
    def standpoint_list(self):
        """Gets the standpoint_list of this CoverSheet.  # noqa: E501


        :return: The standpoint_list of this CoverSheet.  # noqa: E501
        :rtype: DocumentEntryList
        """
        return self._standpoint_list

    @standpoint_list.setter
    def standpoint_list(self, standpoint_list):
        """Sets the standpoint_list of this CoverSheet.


        :param standpoint_list: The standpoint_list of this CoverSheet.  # noqa: E501
        :type: DocumentEntryList
        """

        self._standpoint_list = standpoint_list

    @property
    def choice_company_ovz_statement(self):
        """Gets the choice_company_ovz_statement of this CoverSheet.  # noqa: E501

        Vyjádření OVZ/Protokol o výběhu nejvýhodnější nabídky/Výjimka ministra  # noqa: E501

        :return: The choice_company_ovz_statement of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._choice_company_ovz_statement

    @choice_company_ovz_statement.setter
    def choice_company_ovz_statement(self, choice_company_ovz_statement):
        """Sets the choice_company_ovz_statement of this CoverSheet.

        Vyjádření OVZ/Protokol o výběhu nejvýhodnější nabídky/Výjimka ministra  # noqa: E501

        :param choice_company_ovz_statement: The choice_company_ovz_statement of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._choice_company_ovz_statement = choice_company_ovz_statement

    @property
    def choice_company_ovz_statement_attachments(self):
        """Gets the choice_company_ovz_statement_attachments of this CoverSheet.  # noqa: E501

        Souborové přílohy k Vyjádření OVZ/Protokol o výběhu nejvýhodnější nabídky/Výjimka ministra   # noqa: E501

        :return: The choice_company_ovz_statement_attachments of this CoverSheet.  # noqa: E501
        :rtype: list[DocumentAttachment]
        """
        return self._choice_company_ovz_statement_attachments

    @choice_company_ovz_statement_attachments.setter
    def choice_company_ovz_statement_attachments(self, choice_company_ovz_statement_attachments):
        """Sets the choice_company_ovz_statement_attachments of this CoverSheet.

        Souborové přílohy k Vyjádření OVZ/Protokol o výběhu nejvýhodnější nabídky/Výjimka ministra   # noqa: E501

        :param choice_company_ovz_statement_attachments: The choice_company_ovz_statement_attachments of this CoverSheet.  # noqa: E501
        :type: list[DocumentAttachment]
        """

        self._choice_company_ovz_statement_attachments = choice_company_ovz_statement_attachments

    @property
    def choice_company_ovz_statement_attachments_old(self):
        """Gets the choice_company_ovz_statement_attachments_old of this CoverSheet.  # noqa: E501

        Souborové přílohy k Vyjádření OVZ/Protokol o výběhu nejvýhodnější nabídky/Výjimka ministra - RTF   # noqa: E501

        :return: The choice_company_ovz_statement_attachments_old of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._choice_company_ovz_statement_attachments_old

    @choice_company_ovz_statement_attachments_old.setter
    def choice_company_ovz_statement_attachments_old(self, choice_company_ovz_statement_attachments_old):
        """Sets the choice_company_ovz_statement_attachments_old of this CoverSheet.

        Souborové přílohy k Vyjádření OVZ/Protokol o výběhu nejvýhodnější nabídky/Výjimka ministra - RTF   # noqa: E501

        :param choice_company_ovz_statement_attachments_old: The choice_company_ovz_statement_attachments_old of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._choice_company_ovz_statement_attachments_old = choice_company_ovz_statement_attachments_old

    @property
    def draft_contract_attachments(self):
        """Gets the draft_contract_attachments of this CoverSheet.  # noqa: E501

        Attachments_Draft_Contract - Přílohy - návrh smlouvy nebo dodatku  # noqa: E501

        :return: The draft_contract_attachments of this CoverSheet.  # noqa: E501
        :rtype: list[DocumentAttachment]
        """
        return self._draft_contract_attachments

    @draft_contract_attachments.setter
    def draft_contract_attachments(self, draft_contract_attachments):
        """Sets the draft_contract_attachments of this CoverSheet.

        Attachments_Draft_Contract - Přílohy - návrh smlouvy nebo dodatku  # noqa: E501

        :param draft_contract_attachments: The draft_contract_attachments of this CoverSheet.  # noqa: E501
        :type: list[DocumentAttachment]
        """

        self._draft_contract_attachments = draft_contract_attachments

    @property
    def draft_contract_attachments_old(self):
        """Gets the draft_contract_attachments_old of this CoverSheet.  # noqa: E501

        Attachments_Draft_Contract - Přílohy - návrh smlouvy nebo dodatku - RTF  # noqa: E501

        :return: The draft_contract_attachments_old of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._draft_contract_attachments_old

    @draft_contract_attachments_old.setter
    def draft_contract_attachments_old(self, draft_contract_attachments_old):
        """Sets the draft_contract_attachments_old of this CoverSheet.

        Attachments_Draft_Contract - Přílohy - návrh smlouvy nebo dodatku - RTF  # noqa: E501

        :param draft_contract_attachments_old: The draft_contract_attachments_old of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._draft_contract_attachments_old = draft_contract_attachments_old

    @property
    def signed_contract_attachments(self):
        """Gets the signed_contract_attachments of this CoverSheet.  # noqa: E501

        Attachments_Signed_Contract -  Přílohy - podepsaná smlouva  # noqa: E501

        :return: The signed_contract_attachments of this CoverSheet.  # noqa: E501
        :rtype: list[DocumentAttachment]
        """
        return self._signed_contract_attachments

    @signed_contract_attachments.setter
    def signed_contract_attachments(self, signed_contract_attachments):
        """Sets the signed_contract_attachments of this CoverSheet.

        Attachments_Signed_Contract -  Přílohy - podepsaná smlouva  # noqa: E501

        :param signed_contract_attachments: The signed_contract_attachments of this CoverSheet.  # noqa: E501
        :type: list[DocumentAttachment]
        """

        self._signed_contract_attachments = signed_contract_attachments

    @property
    def signed_contract_attachments_old(self):
        """Gets the signed_contract_attachments_old of this CoverSheet.  # noqa: E501

        Attachments_Signed_Contract -  Přílohy - podepsaná smlouva - RTF  # noqa: E501

        :return: The signed_contract_attachments_old of this CoverSheet.  # noqa: E501
        :rtype: str
        """
        return self._signed_contract_attachments_old

    @signed_contract_attachments_old.setter
    def signed_contract_attachments_old(self, signed_contract_attachments_old):
        """Sets the signed_contract_attachments_old of this CoverSheet.

        Attachments_Signed_Contract -  Přílohy - podepsaná smlouva - RTF  # noqa: E501

        :param signed_contract_attachments_old: The signed_contract_attachments_old of this CoverSheet.  # noqa: E501
        :type: str
        """

        self._signed_contract_attachments_old = signed_contract_attachments_old

    @property
    def oldcontract_scan_deliver_later(self):
        """Gets the oldcontract_scan_deliver_later of this CoverSheet.  # noqa: E501

        oldcontract_scan_deliver_later - podepsaná smlouva bude vložena později  # noqa: E501

        :return: The oldcontract_scan_deliver_later of this CoverSheet.  # noqa: E501
        :rtype: bool
        """
        return self._oldcontract_scan_deliver_later

    @oldcontract_scan_deliver_later.setter
    def oldcontract_scan_deliver_later(self, oldcontract_scan_deliver_later):
        """Sets the oldcontract_scan_deliver_later of this CoverSheet.

        oldcontract_scan_deliver_later - podepsaná smlouva bude vložena později  # noqa: E501

        :param oldcontract_scan_deliver_later: The oldcontract_scan_deliver_later of this CoverSheet.  # noqa: E501
        :type: bool
        """

        self._oldcontract_scan_deliver_later = oldcontract_scan_deliver_later

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CoverSheet, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CoverSheet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from esmlouvy_connector.api_client import ApiClient


class AdminsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_config(self, **kwargs):  # noqa: E501
        """získá konfiguraci konektoru  # noqa: E501

        Získá nastavení konektoru  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_config(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_config_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_config_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_config_with_http_info(self, **kwargs):  # noqa: E501
        """získá konfiguraci konektoru  # noqa: E501

        Získá nastavení konektoru  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_config_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_config" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/config', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_profile(self, **kwargs):  # noqa: E501
        """získá konfiguraci databáze serveru Domino  # noqa: E501

        Získá hlavní profil aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_profile(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ProfileMain
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_profile_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_profile_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_profile_with_http_info(self, **kwargs):  # noqa: E501
        """získá konfiguraci databáze serveru Domino  # noqa: E501

        Získá hlavní profil aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_profile_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ProfileMain
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_profile" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/profile', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProfileMain',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_profile_dir(self, **kwargs):  # noqa: E501
        """získá pomocný profil (řízené slovníky) konfigurace databáze serveru Domino  # noqa: E501

        Získá pomocný profil aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_profile_dir(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ProfileDirectory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_profile_dir_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_profile_dir_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_profile_dir_with_http_info(self, **kwargs):  # noqa: E501
        """získá pomocný profil (řízené slovníky) konfigurace databáze serveru Domino  # noqa: E501

        Získá pomocný profil aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_profile_dir_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ProfileDirectory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_profile_dir" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/profile_dir', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProfileDirectory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_profile_roles(self, **kwargs):  # noqa: E501
        """získá pomocný profil (role) konfigurace databáze serveru Domino  # noqa: E501

        Získá pomocný profil rolí aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_profile_roles(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ProfileRoles
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_profile_roles_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_profile_roles_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_profile_roles_with_http_info(self, **kwargs):  # noqa: E501
        """získá pomocný profil (role) konfigurace databáze serveru Domino  # noqa: E501

        Získá pomocný profil rolí aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_profile_roles_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ProfileRoles
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_profile_roles" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/profile_roles', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProfileRoles',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_config(self, **kwargs):  # noqa: E501
        """aktualizuje hlavní konfiguraci konektoru  # noqa: E501

        Aktualizuje konfiguraci konektoru  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_config(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ConfigBody body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_config_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.put_config_with_http_info(**kwargs)  # noqa: E501
            return data

    def put_config_with_http_info(self, **kwargs):  # noqa: E501
        """aktualizuje hlavní konfiguraci konektoru  # noqa: E501

        Aktualizuje konfiguraci konektoru  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_config_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ConfigBody body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_config" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/config', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_profile(self, **kwargs):  # noqa: E501
        """aktualizuje nebo vytvoří hlavní konfiguraci aplikace Domino  # noqa: E501

        Aktualizuje hlavní profil aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_profile(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProfileMain body:
        :return: ProfileMain
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_profile_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.put_profile_with_http_info(**kwargs)  # noqa: E501
            return data

    def put_profile_with_http_info(self, **kwargs):  # noqa: E501
        """aktualizuje nebo vytvoří hlavní konfiguraci aplikace Domino  # noqa: E501

        Aktualizuje hlavní profil aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_profile_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProfileMain body:
        :return: ProfileMain
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_profile" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/profile', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProfileMain',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_profile_dir(self, **kwargs):  # noqa: E501
        """aktualizuje nebo vytvoří pomocný profil (řízené slovníky) konfigurace databáze serveru Domino  # noqa: E501

        Aktualizuje nebo vytvoří pomocný profil aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_profile_dir(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProfileDirectory body:
        :return: ProfileDirectory
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_profile_dir_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.put_profile_dir_with_http_info(**kwargs)  # noqa: E501
            return data

    def put_profile_dir_with_http_info(self, **kwargs):  # noqa: E501
        """aktualizuje nebo vytvoří pomocný profil (řízené slovníky) konfigurace databáze serveru Domino  # noqa: E501

        Aktualizuje nebo vytvoří pomocný profil aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_profile_dir_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProfileDirectory body:
        :return: ProfileDirectory
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_profile_dir" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/profile_dir', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProfileDirectory',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def put_profile_roles(self, **kwargs):  # noqa: E501
        """aktualizuje nebo vytvoří pomocný profil (role) konfigurace databáze serveru Domino  # noqa: E501

        Aktualizuje nebo vytvoří pomocný profil rolí aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_profile_roles(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProfileRoles body:
        :return: ProfileRoles
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.put_profile_roles_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.put_profile_roles_with_http_info(**kwargs)  # noqa: E501
            return data

    def put_profile_roles_with_http_info(self, **kwargs):  # noqa: E501
        """aktualizuje nebo vytvoří pomocný profil (role) konfigurace databáze serveru Domino  # noqa: E501

        Aktualizuje nebo vytvoří pomocný profil rolí aplikace Domino  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.put_profile_roles_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProfileRoles body:
        :return: ProfileRoles
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_profile_roles" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/profile_roles', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProfileRoles',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def replace_name(self, **kwargs):  # noqa: E501
        """Zamění jméno ve všech dokumentech a polích, kde se vyskytuje  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_name(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReplaceName body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.replace_name_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.replace_name_with_http_info(**kwargs)  # noqa: E501
            return data

    def replace_name_with_http_info(self, **kwargs):  # noqa: E501
        """Zamění jméno ve všech dokumentech a polích, kde se vyskytuje  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_name_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReplaceName body:
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace_name" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiKey']  # noqa: E501

        return self.api_client.call_api(
            '/replace_name', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentAttachment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'title': 'str',
        'creator': 'str',
        'date_uploaded': 'datetime',
        'attachment_field': 'str',
        'attachment_type': 'str',
        'attachment_subtype': 'str',
        'mime_type': 'str',
        'size': 'int',
        'storage': 'str',
        'container_id': 'str',
        'document_id': 'str',
        'identifier': 'str',
        'domino': 'DominoCommons',
        'acl': 'GeneralAcl'
    }

    attribute_map = {
        'name': 'name',
        'title': 'title',
        'creator': 'creator',
        'date_uploaded': 'date_uploaded',
        'attachment_field': 'attachment_field',
        'attachment_type': 'attachment_type',
        'attachment_subtype': 'attachment_subtype',
        'mime_type': 'mime_type',
        'size': 'size',
        'storage': 'storage',
        'container_id': 'container_id',
        'document_id': 'document_id',
        'identifier': 'identifier',
        'domino': 'domino',
        'acl': 'acl'
    }

    def __init__(self, name=None, title=None, creator=None, date_uploaded=None, attachment_field=None, attachment_type=None, attachment_subtype=None, mime_type=None, size=None, storage=None, container_id=None, document_id=None, identifier=None, domino=None, acl=None):  # noqa: E501
        """DocumentAttachment - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._title = None
        self._creator = None
        self._date_uploaded = None
        self._attachment_field = None
        self._attachment_type = None
        self._attachment_subtype = None
        self._mime_type = None
        self._size = None
        self._storage = None
        self._container_id = None
        self._document_id = None
        self._identifier = None
        self._domino = None
        self._acl = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if title is not None:
            self.title = title
        if creator is not None:
            self.creator = creator
        if date_uploaded is not None:
            self.date_uploaded = date_uploaded
        if attachment_field is not None:
            self.attachment_field = attachment_field
        if attachment_type is not None:
            self.attachment_type = attachment_type
        if attachment_subtype is not None:
            self.attachment_subtype = attachment_subtype
        if mime_type is not None:
            self.mime_type = mime_type
        if size is not None:
            self.size = size
        if storage is not None:
            self.storage = storage
        if container_id is not None:
            self.container_id = container_id
        if document_id is not None:
            self.document_id = document_id
        self.identifier = identifier
        if domino is not None:
            self.domino = domino
        if acl is not None:
            self.acl = acl

    @property
    def name(self):
        """Gets the name of this DocumentAttachment.  # noqa: E501

        Attachment name for display  # noqa: E501

        :return: The name of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DocumentAttachment.

        Attachment name for display  # noqa: E501

        :param name: The name of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def title(self):
        """Gets the title of this DocumentAttachment.  # noqa: E501

        Attachment title for display  # noqa: E501

        :return: The title of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this DocumentAttachment.

        Attachment title for display  # noqa: E501

        :param title: The title of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def creator(self):
        """Gets the creator of this DocumentAttachment.  # noqa: E501

        Osoba, která uploadovala přílohu  # noqa: E501

        :return: The creator of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this DocumentAttachment.

        Osoba, která uploadovala přílohu  # noqa: E501

        :param creator: The creator of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._creator = creator

    @property
    def date_uploaded(self):
        """Gets the date_uploaded of this DocumentAttachment.  # noqa: E501

        Datum uploadu přílohy  # noqa: E501

        :return: The date_uploaded of this DocumentAttachment.  # noqa: E501
        :rtype: datetime
        """
        return self._date_uploaded

    @date_uploaded.setter
    def date_uploaded(self, date_uploaded):
        """Sets the date_uploaded of this DocumentAttachment.

        Datum uploadu přílohy  # noqa: E501

        :param date_uploaded: The date_uploaded of this DocumentAttachment.  # noqa: E501
        :type: datetime
        """

        self._date_uploaded = date_uploaded

    @property
    def attachment_field(self):
        """Gets the attachment_field of this DocumentAttachment.  # noqa: E501

        RTF pole uložení přílohy  # noqa: E501

        :return: The attachment_field of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._attachment_field

    @attachment_field.setter
    def attachment_field(self, attachment_field):
        """Sets the attachment_field of this DocumentAttachment.

        RTF pole uložení přílohy  # noqa: E501

        :param attachment_field: The attachment_field of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._attachment_field = attachment_field

    @property
    def attachment_type(self):
        """Gets the attachment_type of this DocumentAttachment.  # noqa: E501

        Typ přílohy - z číselníku typů  # noqa: E501

        :return: The attachment_type of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """Sets the attachment_type of this DocumentAttachment.

        Typ přílohy - z číselníku typů  # noqa: E501

        :param attachment_type: The attachment_type of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._attachment_type = attachment_type

    @property
    def attachment_subtype(self):
        """Gets the attachment_subtype of this DocumentAttachment.  # noqa: E501

        Typ přílohy - z číselníku typů  # noqa: E501

        :return: The attachment_subtype of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._attachment_subtype

    @attachment_subtype.setter
    def attachment_subtype(self, attachment_subtype):
        """Sets the attachment_subtype of this DocumentAttachment.

        Typ přílohy - z číselníku typů  # noqa: E501

        :param attachment_subtype: The attachment_subtype of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._attachment_subtype = attachment_subtype

    @property
    def mime_type(self):
        """Gets the mime_type of this DocumentAttachment.  # noqa: E501

        Attachment mime type  # noqa: E501

        :return: The mime_type of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this DocumentAttachment.

        Attachment mime type  # noqa: E501

        :param mime_type: The mime_type of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._mime_type = mime_type

    @property
    def size(self):
        """Gets the size of this DocumentAttachment.  # noqa: E501

        File size  # noqa: E501

        :return: The size of this DocumentAttachment.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this DocumentAttachment.

        File size  # noqa: E501

        :param size: The size of this DocumentAttachment.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def storage(self):
        """Gets the storage of this DocumentAttachment.  # noqa: E501

        Replica ID storage application  # noqa: E501

        :return: The storage of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._storage

    @storage.setter
    def storage(self, storage):
        """Sets the storage of this DocumentAttachment.

        Replica ID storage application  # noqa: E501

        :param storage: The storage of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._storage = storage

    @property
    def container_id(self):
        """Gets the container_id of this DocumentAttachment.  # noqa: E501

        Container unique identifier  # noqa: E501

        :return: The container_id of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this DocumentAttachment.

        Container unique identifier  # noqa: E501

        :param container_id: The container_id of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def document_id(self):
        """Gets the document_id of this DocumentAttachment.  # noqa: E501

        Source document unique identifier  # noqa: E501

        :return: The document_id of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this DocumentAttachment.

        Source document unique identifier  # noqa: E501

        :param document_id: The document_id of this DocumentAttachment.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def identifier(self):
        """Gets the identifier of this DocumentAttachment.  # noqa: E501

        Attachment unique identifier  # noqa: E501

        :return: The identifier of this DocumentAttachment.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this DocumentAttachment.

        Attachment unique identifier  # noqa: E501

        :param identifier: The identifier of this DocumentAttachment.  # noqa: E501
        :type: str
        """
        if identifier is None:
            raise ValueError("Invalid value for `identifier`, must not be `None`")  # noqa: E501

        self._identifier = identifier

    @property
    def domino(self):
        """Gets the domino of this DocumentAttachment.  # noqa: E501


        :return: The domino of this DocumentAttachment.  # noqa: E501
        :rtype: DominoCommons
        """
        return self._domino

    @domino.setter
    def domino(self, domino):
        """Sets the domino of this DocumentAttachment.


        :param domino: The domino of this DocumentAttachment.  # noqa: E501
        :type: DominoCommons
        """

        self._domino = domino

    @property
    def acl(self):
        """Gets the acl of this DocumentAttachment.  # noqa: E501


        :return: The acl of this DocumentAttachment.  # noqa: E501
        :rtype: GeneralAcl
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this DocumentAttachment.


        :param acl: The acl of this DocumentAttachment.  # noqa: E501
        :type: GeneralAcl
        """

        self._acl = acl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentAttachment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentAttachment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from esmlouvy_connector.api.admins_api import AdminsApi
from esmlouvy_connector.api.attachments_api import AttachmentsApi
from esmlouvy_connector.api.developers_api import DevelopersApi
from esmlouvy_connector.api.public_api import PublicApi



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProfileDirectory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domino': 'DominoCommons',
        'categories': 'list[str]',
        'value_title': 'str',
        'value_description': 'str',
        'value_name': 'list[str]',
        'value_code': 'list[str]',
        'values': 'list[str]'
    }

    attribute_map = {
        'domino': 'domino',
        'categories': 'categories',
        'value_title': 'value_title',
        'value_description': 'value_description',
        'value_name': 'value_name',
        'value_code': 'value_code',
        'values': 'values'
    }

    def __init__(self, domino=None, categories=None, value_title=None, value_description=None, value_name=None, value_code=None, values=None):  # noqa: E501
        """ProfileDirectory - a model defined in Swagger"""  # noqa: E501
        self._domino = None
        self._categories = None
        self._value_title = None
        self._value_description = None
        self._value_name = None
        self._value_code = None
        self._values = None
        self.discriminator = None
        if domino is not None:
            self.domino = domino
        if categories is not None:
            self.categories = categories
        if value_title is not None:
            self.value_title = value_title
        if value_description is not None:
            self.value_description = value_description
        if value_name is not None:
            self.value_name = value_name
        if value_code is not None:
            self.value_code = value_code
        if values is not None:
            self.values = values

    @property
    def domino(self):
        """Gets the domino of this ProfileDirectory.  # noqa: E501


        :return: The domino of this ProfileDirectory.  # noqa: E501
        :rtype: DominoCommons
        """
        return self._domino

    @domino.setter
    def domino(self, domino):
        """Sets the domino of this ProfileDirectory.


        :param domino: The domino of this ProfileDirectory.  # noqa: E501
        :type: DominoCommons
        """

        self._domino = domino

    @property
    def categories(self):
        """Gets the categories of this ProfileDirectory.  # noqa: E501

        Categories - Kategorie  # noqa: E501

        :return: The categories of this ProfileDirectory.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this ProfileDirectory.

        Categories - Kategorie  # noqa: E501

        :param categories: The categories of this ProfileDirectory.  # noqa: E501
        :type: list[str]
        """

        self._categories = categories

    @property
    def value_title(self):
        """Gets the value_title of this ProfileDirectory.  # noqa: E501

        ValueTitle - Název  # noqa: E501

        :return: The value_title of this ProfileDirectory.  # noqa: E501
        :rtype: str
        """
        return self._value_title

    @value_title.setter
    def value_title(self, value_title):
        """Sets the value_title of this ProfileDirectory.

        ValueTitle - Název  # noqa: E501

        :param value_title: The value_title of this ProfileDirectory.  # noqa: E501
        :type: str
        """

        self._value_title = value_title

    @property
    def value_description(self):
        """Gets the value_description of this ProfileDirectory.  # noqa: E501

        ValueDescription - Popis  # noqa: E501

        :return: The value_description of this ProfileDirectory.  # noqa: E501
        :rtype: str
        """
        return self._value_description

    @value_description.setter
    def value_description(self, value_description):
        """Sets the value_description of this ProfileDirectory.

        ValueDescription - Popis  # noqa: E501

        :param value_description: The value_description of this ProfileDirectory.  # noqa: E501
        :type: str
        """

        self._value_description = value_description

    @property
    def value_name(self):
        """Gets the value_name of this ProfileDirectory.  # noqa: E501

        ValueName - Text  # noqa: E501

        :return: The value_name of this ProfileDirectory.  # noqa: E501
        :rtype: list[str]
        """
        return self._value_name

    @value_name.setter
    def value_name(self, value_name):
        """Sets the value_name of this ProfileDirectory.

        ValueName - Text  # noqa: E501

        :param value_name: The value_name of this ProfileDirectory.  # noqa: E501
        :type: list[str]
        """

        self._value_name = value_name

    @property
    def value_code(self):
        """Gets the value_code of this ProfileDirectory.  # noqa: E501

        ValueCode - Zkratka  # noqa: E501

        :return: The value_code of this ProfileDirectory.  # noqa: E501
        :rtype: list[str]
        """
        return self._value_code

    @value_code.setter
    def value_code(self, value_code):
        """Sets the value_code of this ProfileDirectory.

        ValueCode - Zkratka  # noqa: E501

        :param value_code: The value_code of this ProfileDirectory.  # noqa: E501
        :type: list[str]
        """

        self._value_code = value_code

    @property
    def values(self):
        """Gets the values of this ProfileDirectory.  # noqa: E501

        Values - computed  # noqa: E501

        :return: The values of this ProfileDirectory.  # noqa: E501
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this ProfileDirectory.

        Values - computed  # noqa: E501

        :param values: The values of this ProfileDirectory.  # noqa: E501
        :type: list[str]
        """

        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProfileDirectory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProfileDirectory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
